@@ -405,6 +405,7 @@ def _process_component_request(
                         component_id=component_request.id,
                         component_name=component_request.name,
                         request=request,
+                        use_cache=False,
                     )
 
                     #  Explicitly remove all errors and prevent validation from firing before render()
@@ -578,7 +579,9 @@ def _handle_component_request(
     cache = caches[get_cache_alias()]
 
     # Add the current request `ComponentRequest` to the cache
-    component_cache_key = f"{component_request.name}:{component_request.id}"
+    component_cache_key = (
+        f"unicorn:queue:{component_request.name}:{component_request.id}"
+    )
     component_requests = cache.get(component_cache_key) or []
     component_requests.append(component_request)
 
